
# q-expansion of newform 8022.2.a.w, downloaded from the LMFDB on 16 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 8022
weight = 2
poly_data = [-984, 5892, 2178, -21330, -9090, 14926, 4419, -4265, -823, 588, 67, -39, -2, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[8061817040013, -19247930149963, -78597130619222, -33240912944049, 33895606563067, 15268695018202, -4565986413674, -2234594671408, 122626734490, 133824114179, 15438858089, -2774347109, -815360779], 2506799845265], [[2109658591972, -214745031504702, 237447694423082, 499775665432234, -165202210189592, -201427226198297, 45547334660459, 31816857582083, -6152153697530, -2212470155009, 402919256431, 56756216984, -10201546261], 10027199381060], [[94923743332512, -320985486959922, -97901179567998, 443718200238834, -30460052586372, -174164570270677, 28044632606099, 29449468678743, -5974308308370, -2275502227509, 516126759411, 66002861504, -15975601261], 10027199381060], [[-4710957761738, 9414353786698, 7259426594262, -10609671926818, 3615153137533, 4274768056742, -2641988438937, -778545700667, 506243013485, 65253175552, -39731854036, -2040700125, 1125014597], 501359969053], [[7648863907359, 45227910794596, -45119366878836, -122928150064332, -25060998862664, 49383302257961, 17314606769693, -7482308033759, -3100832929910, 487969080462, 224174055562, -11531211217, -5778912177], 2506799845265], [[6322577194703, -26430400325363, -19646402483192, 11500510601706, -30962200340188, -5180491257703, 18316232551881, 1453247687847, -3422496456265, -168708040596, 267566100459, 6580424121, -7570316369], 2506799845265], [[-16751420402088, -107134931750002, 84929378870362, 478251271255534, 184283706691998, -199733774717087, -97194443311251, 30236980923803, 16816439266460, -1929028991339, -1223668410149, 43663595874, 32194159899], 10027199381060], [[-9593832434452, -205844601920058, -720939763442, 608909587654926, 294227406989292, -245322428855043, -131985663639599, 37041530919037, 21146618415910, -2398017470511, -1453126690831, 55963442296, 36445163621], 10027199381060], [[10293529770944, 71039222913256, -235122511140826, -283779074312422, 198774755059566, 137178513041331, -64481397503597, -25278728514469, 9929825300390, 2033768434187, -725515697533, -60061658382, 20200900453], 5013599690530], [[-29243452320498, -4450214792322, 124097916783792, -54566961111346, -229714808589442, 21947601328373, 88766499150029, -2612336668477, -13649386056720, 92773657751, 928022973631, 396387344, -23323354941], 5013599690530], [[33601179974596, 131644417916654, -173960863729554, -101566729327478, 356060701413664, 65315647794119, -147270435604113, -17469639520141, 24241667050450, 1839579098503, -1771870773337, -65641670948, 48130005127], 10027199381060]]

hecke_ring_character_values = None
aps_data = [[-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1], [1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, -1, 1, -1, 0, 1, -1, 0, 0], [1, -1, 0, -1, 0, -1, 1, -1, 0, 1, 0, 1, 0], [0, 0, -1, -1, 1, 0, 0, 0, 0, 1, 0, 1, 0], [1, -1, 0, 1, 0, 0, 0, 0, -1, 1, 1, 0, 0], [-1, -1, 0, 1, 0, 0, 1, 0, 0, 1, 0, 0, 0], [1, 1, 0, -1, 0, 0, -1, 0, 0, -1, -1, 0, 0], [-1, -1, 0, 1, 0, -1, 0, -1, 0, -1, 0, 0, 0], [1, -1, 0, 0, -2, 1, -1, 1, 0, -2, 0, -1, 0], [-2, 1, 0, 0, -1, 0, -1, 2, 0, -3, 0, -2, -2], [2, -2, 2, 1, 0, 1, 0, -1, 0, 0, 0, -1, 1], [1, -1, 0, -1, 1, 0, 1, -1, 0, 1, 0, 0, 1], [1, -1, 1, 0, 0, 0, -1, 1, 0, 0, 2, -1, 1], [2, -2, 1, 1, -1, 0, 0, 0, -1, -1, 2, -1, -1], [-1, 1, 0, 2, -3, 0, 0, 1, -1, -3, -1, -2, -2], [2, 1, 0, -2, 3, -1, 0, -1, 1, 2, 1, 1, 1], [-2, 0, 0, 1, 0, 1, -1, 0, 0, -2, 0, -1, -1], [0, 3, 0, 1, -3, -1, -1, 2, 0, -4, 0, -2, -2], [1, -2, 0, -1, 2, 0, 0, -1, -1, 2, 0, 3, 1], [0, 0, -1, 0, 2, 0, 2, -1, 0, 0, -1, 0, 0], [-2, -1, 1, 2, 0, 1, 0, 0, -2, -1, 0, 0, 0], [2, 1, 0, 1, 1, 0, 3, -1, 0, 1, 0, -1, -1], [0, -3, 1, 1, -3, 0, -1, 0, -2, 0, 2, 0, 1], [4, 2, -2, -3, 1, -1, -1, 1, 0, 1, -1, 1, 1], [-3, -1, 0, 1, -1, 1, -1, 1, 0, -1, 0, -1, 0], [2, -2, 0, -3, 2, 1, 2, 0, 1, 4, -1, 1, 1], [6, 0, 0, -1, -2, 0, -2, 0, 0, -1, 1, 0, 2], [2, 1, 1, -2, -2, 0, -3, 0, 0, -3, 0, -1, 0], [3, 0, 2, 1, -3, 0, -2, -1, 0, 0, 0, -1, 2], [9, 2, 2, -3, 0, 0, -3, 2, 2, 1, 2, 0, 2], [-1, 0, -2, -2, 1, -1, 1, -2, 0, 3, -1, 1, 0], [3, -2, 2, -2, 1, 0, 0, -2, 0, 3, 1, 0, 4], [3, -3, -3, -2, -1, 1, 0, 2, 0, 1, 2, 0, 1], [2, -1, 0, 4, -1, 0, 2, -2, 0, 2, -1, 1, -1], [3, 5, -2, 0, 0, 2, -1, 3, 2, -3, -1, -1, -1], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -2, 0, 4, 0, 0, 1, -1, -3, -1, 0, 1, -1], [0, -2, 0, 2, 3, 0, 3, -1, 1, 3, 0, 0, 0], [2, 0, -1, 0, 0, 1, 0, -2, 0, 1, -1, -1, -1], [3, -4, 0, 3, 1, 0, 6, -2, 0, 3, 0, 0, 1], [4, 0, 1, 1, 2, 2, -1, -1, 0, -2, 0, 1, 1], [-5, -1, 0, 4, 0, -2, 3, -2, -2, -2, -1, -2, -2], [7, 0, -2, -1, 2, 1, -1, -2, 0, 1, 0, 2, 0], [-2, 1, -2, 2, -1, 2, 1, 1, 0, -2, 0, -1, -1], [0, -2, 0, 1, -2, -1, 2, 0, -2, -1, 0, 0, 0], [9, -2, 0, -2, 1, 1, -1, 0, 0, 2, 2, 1, 1], [-3, 2, 0, 3, -3, 0, -1, 0, 0, -1, -2, -1, -1], [3, 3, -1, -3, -2, 1, -6, 4, 2, -5, 1, 0, -2], [8, 0, 0, -3, 1, 0, 1, -2, 0, 2, 1, 2, 2], [2, 1, -4, 0, 3, 0, 3, 0, 0, 3, -1, 0, -2], [4, 2, 0, 1, 0, 1, -2, 1, 2, 0, -1, -1, 1], [5, 3, -4, -1, 2, -2, 2, 1, -2, 1, -2, 0, -2], [0, -1, 0, -1, 1, -2, 3, 0, 0, 0, 0, 0, -2], [3, 4, -4, -1, 2, 0, 1, 1, 3, -1, -1, 2, -2], [4, 4, -2, -2, -2, 0, -1, 1, 4, 0, 0, 0, 0], [5, 0, 2, 0, 3, 0, 1, 0, 0, 0, 1, 1, -1], [-1, -1, 2, -2, -1, -1, 1, -4, -2, 1, 0, 2, 1], [9, -4, 1, -2, 2, 0, 1, -3, 0, 5, 1, -1, 2], [2, -3, 4, 2, -4, -1, -3, 0, 0, 1, 2, -1, 3], [-1, 0, -4, -4, 4, -1, 3, 1, -1, 6, 1, 2, 0], [7, -1, 0, 1, 3, -3, 4, -5, 0, 5, -2, 1, 1], [1, 1, 1, 2, 0, 1, 5, -2, 0, 0, -1, 0, 1], [8, -1, 1, 0, 4, 1, 3, -3, -1, 2, 0, 0, 0], [-3, 4, -1, 0, -1, 1, -3, 4, 0, -6, 2, -3, -4], [-5, 2, 0, 1, 2, -1, 2, 1, 0, 1, 1, -2, 0], [6, -3, 0, 1, -2, -1, 3, 1, -3, 4, 1, 1, 1], [-2, 5, -1, -1, -3, 1, -1, 5, 2, -4, -1, -3, -3], [3, -3, 3, 2, -1, 0, 2, -3, 0, 0, 0, -1, 0], [-1, 1, 3, 2, 1, -2, 4, -4, 0, 3, -1, 0, 1], [5, -2, 6, 6, 0, 1, 1, -2, 0, -2, 2, -2, 0], [11, 2, -2, -4, 1, 1, -2, 2, 3, 4, -1, 3, 1], [-14, 4, -3, 2, 3, -1, 3, -3, 0, 0, -3, 1, -2], [1, 3, 0, 3, -1, 2, -4, 3, 0, -5, -2, -3, -1], [-8, 2, 1, 1, 0, 3, 0, 3, 0, 0, 3, -1, 0], [-5, 4, -2, 5, -2, -1, 1, 2, 0, -5, -2, 0, -4], [7, 4, 0, 2, 0, 0, 1, 0, 2, -2, -2, -2, -2], [5, -3, 0, -2, -7, 2, -5, 5, -4, -5, 1, -2, -2], [5, -5, 0, 1, 2, 1, 3, 0, -1, 4, 0, 1, 1], [-10, 1, -2, 1, 3, 1, 5, -2, 2, 4, -2, 0, 2], [2, 1, -2, -5, 3, 0, -2, -2, 2, -2, -2, 3, 2], [-4, 0, -1, 2, -2, 1, 0, 0, 0, -3, -1, 0, 0], [-7, 3, 4, 3, -4, 1, -1, 0, 0, -7, 2, -4, -2], [-1, 0, 2, 3, -5, 0, -6, 2, 1, -7, 0, -3, 3], [2, -5, 4, 1, 2, -1, 4, -5, 0, 2, -1, 3, 1], [-3, 6, -2, -4, -2, 1, -5, 5, 1, -4, 0, -2, 0], [1, 3, 0, 5, -3, -2, 1, -3, -2, -7, 2, -2, -3], [-1, 2, 3, 1, -1, 2, 2, 4, 2, -1, 2, -2, 0], [-11, -3, 2, 0, 2, 0, 3, -6, -2, 3, 0, 2, -1], [-2, 9, -5, 1, -3, -1, -3, 2, -1, -6, -2, 0, -6], [-1, 5, -2, -2, 3, 4, -2, 5, 3, 1, -1, 2, 0], [1, -3, 5, 2, 2, 1, 3, -2, 2, 3, 4, -1, 3], [3, -4, 2, 0, 0, -2, 5, -5, 0, 1, 1, 1, 1], [2, 2, -1, -4, 6, 1, -1, 1, 2, 2, -1, 2, 3], [6, -4, 3, -2, -2, 0, -4, 1, 0, 7, 2, 1, 4], [6, -1, 0, -1, -1, -2, -4, -1, -2, -4, -1, -2, 0], [-3, 0, 3, 2, -3, -1, 0, -1, 1, 4, 1, -3, 3], [-10, 0, -2, 1, -2, -2, 0, 0, -2, -3, 0, -2, -4], [3, 3, -2, -1, 2, -2, 0, 1, -2, 3, 0, 0, 0], [3, 4, -2, -1, -3, 4, -5, 6, 0, -5, -2, -3, -3], [-4, 6, 0, -2, 3, -1, 0, 2, 2, 0, -3, 1, -1], [2, -8, 5, 5, 0, 0, 1, -1, -2, -3, 1, -2, 1], [7, 9, -4, 1, -3, 0, -4, 0, 0, -6, -2, 0, -4], [-3, -2, 2, 6, -1, -2, 2, -1, 0, -1, -2, 0, -1], [3, 0, 0, -1, 0, 1, -1, 4, 0, -3, -1, -4, 0], [7, 3, -2, -1, 3, 3, 1, 5, 0, -2, -1, 0, -2], [2, 1, 2, -3, 2, 2, -4, 2, 3, -2, 4, -3, 1], [-4, 1, -3, -1, -3, 5, -2, 6, 0, -5, -1, 1, -2], [-8, -1, 0, 4, -2, 2, -1, 3, -2, -7, 3, -2, -5], [1, -4, -4, -2, 1, 2, 3, 2, -2, 3, 3, 1, -2], [-9, 6, -5, -2, -1, -2, -6, 2, 0, -6, -2, -1, -3], [9, 2, -2, 1, -3, 0, -4, 4, -2, 0, -1, 0, -2], [-2, 4, -2, -4, 0, -1, 0, -2, 5, 1, 1, 1, 3], [5, -1, 2, -2, -3, 1, -3, 3, 1, 1, 1, -1, 2], [-5, -2, -4, -1, -2, 1, 2, 0, 2, 4, -1, 1, 1], [6, 3, -3, -5, 7, -2, 2, 0, 2, 4, 4, 1, -1], [1, -4, -2, 6, -2, -1, 2, -4, -4, 1, 0, -1, -3], [10, -1, 4, -3, 5, 1, -1, -2, 2, 4, 0, 2, 4], [-7, -1, 1, 1, -3, -4, -2, 0, 0, 0, 0, 0, -1], [6, -8, -1, 1, 1, -5, 7, -8, -2, 10, 1, 2, 3], [0, -3, 0, -2, 3, 1, 3, -1, -2, 12, 0, 7, 3], [0, -3, 2, -1, -3, -3, -1, -5, -2, -1, 0, 1, 1], [2, -7, 2, 1, 8, -1, 7, -5, 0, 5, -1, 0, 0], [2, 1, 1, 0, -5, 1, -5, 6, -1, -9, 0, -2, -2], [9, 2, 2, 2, -4, 7, -1, 4, 3, -5, -1, -3, 1], [-13, -2, 0, 7, 0, 0, 7, -3, -6, 0, -2, 3, -3], [-3, 2, -4, -2, -2, -3, -6, 4, 0, -1, 1, 3, -3], [9, 0, 2, 4, 2, -1, 2, -2, 0, 1, 3, -3, -1], [-7, -5, -3, -5, -3, -4, -2, -1, -2, 2, -1, 2, 0], [12, -2, 2, -11, 7, -2, 1, -5, 2, 9, 1, 7, 5], [3, -2, -1, 0, -3, -1, -8, -2, -2, -6, 0, 3, 1], [12, -4, -3, -2, 3, 1, 0, -5, 0, 5, -2, 6, 5], [-6, 3, 0, 2, 0, 0, 0, 1, -2, -5, 1, 1, -1], [14, -1, -2, -1, -3, 3, 3, 4, 2, -1, -1, -2, -1], [1, -4, 0, -4, -3, -1, -6, -2, 0, 1, 2, 0, 2], [-2, -3, -2, -7, 0, -2, -5, 2, 0, 1, 1, 1, 2], [7, -1, -3, 0, -1, -3, 5, -2, -4, 2, -1, -3, -2], [-2, 7, 0, 4, -2, 2, -5, 1, 0, -8, -6, -2, -4], [8, 1, 1, 0, 0, -1, 4, -3, 1, -1, -3, -3, -1], [1, -3, 0, -9, 6, -1, 3, -2, 3, 10, 3, 5, 3], [6, -2, -2, -7, 5, -3, 0, 0, 4, 1, 0, 3, 3], [2, 1, 4, 3, 0, -4, -2, -1, 0, 0, 2, 3, 1], [6, 0, -5, -5, 1, -2, 5, 1, -2, 0, -4, 0, -2], [-1, 5, 4, 2, -3, -3, 0, -1, 2, -3, -1, -1, 4], [-10, -7, 2, 7, -5, 2, 1, 2, -3, -3, 5, -3, 3], [-5, -3, -1, -3, 8, 2, 6, -6, 0, 12, -2, 5, 4], [0, 1, 2, 4, -5, 0, 0, 1, -3, -6, 2, -3, -3], [16, -5, 2, -7, 6, 0, 2, -4, 4, 3, -1, 2, 4], [6, 3, 4, -1, 9, -2, 6, -7, 4, 6, -5, 0, 4], [0, -1, 0, 2, 6, 1, 9, -2, -2, 7, 2, -1, -3], [-1, -2, 4, -1, 1, 2, 1, -1, 2, 0, 2, 0, 0], [-4, -4, 5, 3, -2, 3, 2, 2, 0, 0, 3, -7, 3], [6, 6, -4, -3, 0, -4, -3, -1, -2, -4, -4, 3, -4], [2, -3, 3, -1, 1, 1, 7, 1, 2, 4, -1, 4, 4], [-6, 6, -2, 8, -5, 3, 0, 1, 0, -3, -2, -4, -2], [5, 0, 0, 2, -2, 3, -1, 2, -1, 5, 1, 3, 3], [4, 3, -3, 2, 3, 3, 5, -1, -2, 0, -2, -1, -4], [5, 4, 0, -7, 0, -3, 1, 5, 2, -4, 4, 3, -1], [11, -1, -2, -2, 6, -2, 4, 4, 3, 8, 3, 4, 2], [0, 2, 0, -2, 0, 3, -8, 5, 2, 1, 4, 1, 3], [3, 5, -1, 7, 0, 1, 0, 1, 4, -7, -2, -6, -5], [13, -2, 4, 7, -1, 1, 1, -3, 0, -2, 2, -6, 2], [1, 9, -1, 0, -1, -2, -6, -1, 0, -4, -4, 1, -4], [-11, 1, 6, 2, -3, 3, -4, -1, 1, -9, 1, -6, 2], [17, 6, -4, -4, 1, 1, -3, 5, 1, -3, -2, 1, -4], [-1, 3, 2, 5, -5, -1, -1, 2, 2, -7, 1, -7, -3], [-3, 8, 2, 7, -2, 0, -1, -1, -5, -6, 0, 0, -5], [11, -2, 2, 5, 3, -1, 1, -1, 3, 2, 4, -1, -2], [-5, 3, 1, 2, 7, 2, 3, -6, 4, 6, -1, 3, 4], [-19, 7, -6, 9, -5, -2, -1, 5, -2, -4, 0, -4, -8], [-6, -2, -2, -5, 0, 6, -3, 0, 0, 3, -2, 1, 6], [16, -2, -2, -3, -5, 2, -2, 0, 0, -1, 4, -1, -1], [5, -5, -3, -4, 6, -5, 8, -5, 0, 13, 1, 3, -1], [11, 7, 0, 0, -1, 5, -5, 6, 2, -6, 3, 1, -1], [-13, 3, -4, 4, -1, 2, 5, -2, 2, 2, -5, -3, -5], [-4, 3, 4, -1, -3, 2, -3, 0, -4, 2, 6, -2, 4], [-8, 6, -4, 1, -4, 2, -3, 7, 0, -5, 1, -2, -2], [11, 3, -6, -5, -5, 5, -13, 13, 0, -6, 2, 0, 0], [6, -6, 5, -2, 6, 0, 4, -7, -2, 10, 3, 1, 7], [3, 6, 1, -3, 3, -1, -5, 0, 0, 0, -1, -2, 6], [23, -1, 4, 0, -4, -3, -2, 2, 0, 1, 4, -1, 3], [-13, 1, 3, 3, 2, -2, -1, 0, 0, 2, -2, -1, 1], [-12, -6, 0, 1, 0, 0, 8, -6, 0, 1, -2, -2, 0], [-5, -5, 1, 4, -8, 1, -4, 5, -2, -12, 3, -4, -3], [13, -8, -2, 1, -2, 0, 3, -3, -2, 2, 1, 3, -1], [-2, 5, -2, -6, 6, -2, 0, -6, 1, 5, -2, 1, 3], [-4, -3, -2, 3, 1, 3, -3, -2, 0, -2, 2, 0, 0], [0, 10, -3, -1, 6, -5, 1, -1, 4, 5, -3, 2, -1], [19, -3, -2, -1, -5, 4, -3, 7, 2, -4, 5, -2, 0], [-1, 7, -2, -2, -5, -4, -3, 3, 0, -7, -2, 0, -2], [8, -8, 2, 4, 5, -4, 7, -9, -4, 10, 5, 5, 3], [-5, -6, 6, 0, -2, 1, -1, -2, 2, 4, 2, 0, 4], [4, 4, -3, 0, 2, 2, -4, 2, 0, -1, -3, 3, -5], [12, 7, -3, -5, 3, 0, -9, 6, 1, 2, 0, 0, 0], [-6, 0, 0, 10, -5, 3, 1, -1, 2, -10, -5, -3, -3], [-8, -3, 0, 8, -3, -4, 1, 1, 2, -8, -3, -9, -1], [10, -1, 4, -6, 0, 1, -3, 2, -6, -3, 6, 1, 1], [-7, -10, 0, 2, -7, 2, -1, 2, -4, -4, 4, -3, 1], [-25, 1, -1, 2, -5, 1, -3, 0, -2, -5, 0, 0, 2], [10, -2, -4, -5, 4, -5, 8, -6, 3, 8, -1, 3, -1], [-5, 2, -8, -4, 7, -7, 7, -2, -4, 4, -3, 3, -3], [3, -3, 0, -5, -2, 0, -2, -2, 4, 2, 2, 1, 3], [-15, 2, -3, 8, 3, -5, 7, -5, -2, 5, -2, -4, -1], [3, 7, 2, -8, -3, 1, -10, 3, 4, -8, 1, -5, -1], [1, 5, -4, -10, 9, 2, 3, -1, 6, 7, -7, 2, 6], [1, -2, 3, -8, 2, 3, -3, -2, 0, 6, 4, 2, 7], [-15, -4, 0, -3, -1, -2, 5, -3, -8, 7, 3, 2, -1], [-9, -1, -4, 6, 4, 0, 4, -9, -2, 3, -3, 1, 0], [-10, -1, 6, 8, 1, -3, 3, -7, 0, -2, 0, -1, -3], [-10, -14, -1, -4, 6, 0, -4, -2, -2, 3, 5, 3, 5], [-4, 2, 0, 3, -7, -1, -7, 2, -2, -3, 4, -4, 7], [-10, 1, 4, 1, -10, 1, -9, 4, 0, -12, -2, -9, -1], [7, 7, 2, 1, -5, -3, 4, 2, -2, -6, -2, -2, -4], [-11, 3, -2, 5, -1, 1, -2, -7, 1, 0, -3, -2, 2], [10, 0, 1, -6, 6, 4, -2, 3, 4, 3, 10, 1, 6], [5, 5, 0, -4, 0, -2, -8, 2, 1, -2, 3, 4, -4], [-8, 3, 6, -4, 3, -3, 7, -6, 2, 3, -4, 4, 2], [-4, -2, -3, -6, 0, 0, -2, -1, 4, 3, 0, 5, 0], [-2, 4, 2, 0, 4, -5, -1, 0, 0, 1, 3, 1, -1], [-14, -5, 2, 3, -8, -4, -1, -8, -4, 0, -4, 1, 1], [-10, 10, 2, 0, 2, 1, 2, 1, 2, 1, 0, -1, -1], [19, -1, -2, -5, 7, -5, -3, -1, 4, 10, 3, 4, 2], [2, -1, -5, 5, 2, 0, 6, 2, -2, 7, -3, 2, -9], [-2, 10, 0, -2, -1, 4, -1, 7, 4, 0, 5, -5, -5], [1, 2, 3, 5, -9, 1, -2, 3, 0, -6, 4, -3, -9], [-6, 5, -2, -7, 1, 4, -2, 10, 2, -3, 4, 1, -1], [-13, 6, 1, 3, -5, 3, 1, 3, 0, -12, 4, -4, -7], [7, -7, 6, 1, -3, 1, -8, 5, 0, -3, 6, -3, 3], [-11, 7, -4, 3, -4, 0, 1, 2, 2, -1, -2, 0, 4], [9, 3, -6, 0, 5, 6, -2, 3, 4, -2, 5, 3, -1], [-3, -4, 7, 6, -5, -3, -3, -7, -4, -2, 1, -7, 3], [-14, -6, 0, 2, -4, 7, 2, -4, -3, -3, -1, -1, 1], [-12, -6, 1, -2, -6, 4, -4, 2, -10, -4, 6, -2, -3], [3, -9, 2, -3, -1, 2, -1, 1, 0, 4, -1, 2, 4], [2, 4, 0, 8, -6, 4, 0, 0, 0, -2, -4, -2, -2], [-3, -7, 5, 4, -3, -2, -1, -1, 0, 1, -1, 0, 5], [-6, 5, -2, 4, -10, -4, 1, 2, 2, -5, -3, -3, -7], [-10, -1, 2, -2, 5, -1, 4, -4, 4, 5, 0, 1, 0], [-10, -2, -2, 0, 0, -1, -1, 1, 0, 6, 1, 2, 0], [-8, -2, 6, 8, -5, 2, -6, 2, 0, -4, 6, -3, -1], [-26, 8, -2, 7, -6, 2, 1, 6, 0, -12, -6, -5, -13], [4, 6, -2, -2, 0, 1, -1, 2, 2, 3, 1, 3, -1], [5, -4, -2, -8, 6, 2, 1, -3, 0, 9, -4, 5, 5], [-6, -8, 4, 7, 2, 0, 9, -6, 5, 10, -1, -2, 3], [14, -1, -2, -7, 0, 4, -1, -2, -4, 6, 8, -1, 1], [-13, -4, 4, 0, -5, -4, -6, 0, -8, -5, 6, 0, 2], [9, -5, 0, -1, -3, 5, 2, 5, -4, 3, 6, -3, 1], [3, -6, -2, -3, 4, -3, 1, -7, 0, 6, 0, 5, 7], [9, -3, 0, -4, 2, 2, -3, 6, 2, 4, 0, -4, 4], [-6, 0, 4, 5, 8, 3, 5, -8, 2, 4, -1, -3, 1], [4, 4, 0, -2, -2, 1, 3, 6, 3, -7, 5, -2, 1], [-10, -3, 10, 7, -2, -2, 13, -3, -4, 1, -1, -2, -4], [5, -1, 1, 2, -9, 5, -6, 10, 0, -10, 1, -5, 1], [18, 8, 0, -7, -3, -3, -6, 1, 0, -6, 2, -4, 2], [14, -9, 8, 0, -3, 2, -2, -4, 1, 3, 4, -4, 6], [-7, 6, -4, 2, 1, -3, -3, -4, 0, -6, -6, 5, -3], [-18, 3, -2, 5, 2, -3, 1, 1, -6, -3, 4, -6, -2], [-4, -2, 0, 0, 9, -3, 4, -7, -4, 7, 0, 6, -4], [7, -1, 3, -7, 2, -4, 2, -4, 4, 4, -6, 7, 0], [-19, -3, 6, 10, -16, 5, -4, 8, -2, -19, 1, -13, -3], [-14, 1, -4, -1, 7, -3, 0, 0, 2, -1, 1, 5, 1], [-14, 13, -4, 4, -3, 6, 5, 7, 4, -8, -2, -7, -3], [-2, 5, 2, -3, 0, 2, -4, 3, 4, -7, -2, 1, 0], [8, 5, 6, 4, -6, 0, -4, 4, -4, -6, 5, 0, 0], [-10, 13, 0, -1, 3, -3, -2, -6, 2, -5, -5, 1, -1], [-13, 7, -5, -3, 5, -10, 1, -7, 0, 4, -5, 4, 5], [-23, -9, 2, 2, 0, 7, -3, 2, 0, 2, 3, -6, 2], [-11, 3, 6, -6, 3, 0, -2, -1, 1, -3, 1, -2, 0], [23, -6, 1, -11, 9, 1, 6, -2, -1, 16, 5, 8, 6], [5, -3, -4, 1, 0, 2, -10, 7, -6, -9, 1, 0, -2], [2, 5, 0, 13, -3, -2, 2, -1, -3, -3, 0, 1, -11], [3, -9, 1, 1, 12, -1, 5, -7, 2, 16, -1, 7, 8], [-22, -1, -4, 9, -5, 0, 0, -2, -8, -9, -7, -5, -9], [-15, -6, -4, -1, 8, 5, 6, -3, -2, 11, -5, 12, 4], [-6, -11, 1, 2, 4, 2, -4, -3, -4, 4, 4, 0, 0], [3, -7, 4, 2, -9, 2, -4, 6, -2, -5, 0, -2, 2], [0, -4, 3, -8, -2, 2, 3, -3, 2, 2, -6, 2, 3], [8, -9, 8, -9, 1, -1, -1, -8, -4, 6, 6, 4, 10], [-5, 6, -5, 3, 4, -2, 4, -5, 4, 2, -4, 1, -5], [1, 4, -9, -2, 0, -1, 2, 2, -2, -1, -1, 5, -8], [5, -11, 7, -6, 0, 4, -4, -1, 0, 4, 4, 2, 9], [-8, 16, -3, 5, -13, -2, -12, 12, -2, -21, -4, -11, -14], [-21, 5, -7, -6, 4, -3, -1, 1, 2, 2, -6, 4, -2], [0, -5, 4, 3, 1, 2, -2, -3, 1, 11, 4, 1, 3], [-5, 2, 0, 3, -6, 1, -3, 7, -4, -3, 1, -3, -8], [-20, -15, 5, 9, -13, 6, -7, 7, -5, -13, 4, -7, -3], [-8, -7, 4, 8, -2, -3, 6, -1, -4, -2, 2, -7, -8], [-24, 2, 3, 3, -3, 1, -3, -3, 2, -3, 2, 1, 2], [-1, 15, -4, -5, 0, 7, -9, 7, 2, -12, -3, -5, -1], [-4, -1, 3, -1, -1, -4, 4, -4, -4, 4, 2, 6, 0], [-6, 7, 0, -2, 10, -2, -1, -3, 3, -1, -3, 1, 7], [-19, 1, -8, -6, -4, 0, 0, 6, 0, 1, -2, -1, -7], [9, 2, 0, -7, 4, -3, 2, 1, -4, -1, 1, 4, -8], [-1, -2, -4, -5, -3, 3, -9, 6, 3, 0, 1, -2, 6], [2, 4, -4, -5, 0, 2, 1, 6, 4, 6, -2, -3, -1], [0, 5, -8, -4, 4, 4, -6, 8, -2, 3, -2, 4, -1], [-4, -4, 4, -2, -6, -3, -6, 5, 4, -5, 0, -3, 7], [-24, -1, -2, 1, 2, 4, 7, -3, -2, 7, -2, 4, 0], [-2, -11, 12, 4, -2, -1, 5, -7, 1, 3, 3, -3, 1], [-10, 1, 2, 5, -11, -3, 0, 5, -1, -1, 6, -1, -3], [-9, 5, 2, 5, 0, 4, -2, 4, 1, -8, 6, -6, 1], [-5, 10, 2, 12, 6, 0, 6, 3, -2, -2, 1, -4, 0], [2, -5, -4, -11, 3, -8, 9, -5, -2, 13, 2, 9, 3], [-25, 7, -2, 9, -4, -1, -3, 0, 2, -12, 0, -2, -7], [5, 14, -10, -8, 7, -1, -6, 4, 4, -5, -6, 6, -2], [10, -15, 8, 9, 2, 2, 6, -8, -4, 7, 3, -4, 8], [20, -3, 0, -6, -2, 7, 0, 7, 3, 0, 4, 0, 0], [-17, 4, 2, 4, -3, -3, 8, -2, 0, -7, -3, -6, -6], [-2, 2, -2, -1, -1, -3, -4, 4, 0, -7, 2, -5, -9], [8, -3, -5, 2, -3, 2, 1, -1, -1, 4, 0, 1, -9], [-26, -4, -1, 3, 6, 2, 11, -7, -5, 13, 1, 2, 0], [11, 5, -4, -9, 3, -3, -9, 4, 4, -1, -7, -1, 7], [-1, -4, 2, -3, -10, 1, -7, 5, -2, 0, 2, -5, 5], [-16, 10, -1, 2, 9, -3, 4, -3, 2, -5, -6, 0, 1], [-12, -4, -6, -6, 4, -3, 8, -2, 3, 13, 1, 3, 1], [-2, -8, 4, 1, -2, 3, 2, 1, -1, 3, -3, -6, 8], [-12, 11, 0, 12, -7, 0, 7, -1, 2, -10, -5, 1, -7], [4, 7, 2, 5, 10, -4, 9, -6, 0, 8, 4, 3, 3], [4, -11, -4, -9, 6, -4, 7, -7, 2, 16, 1, 8, 11], [1, 10, 2, 1, 7, -6, 4, 0, 0, 6, 1, 4, 0], [2, -10, -6, -7, 0, 1, -6, 4, 0, -4, 5, 0, 7], [-5, -6, 8, 3, -4, 4, -1, 6, -5, -6, -1, -5, -3], [24, -3, 7, -1, -7, 12, -3, 5, 0, -11, 2, -5, 0], [9, -3, -2, 7, 2, -4, 6, 4, 0, 5, 1, 3, -4], [-25, -17, 0, 13, 3, 2, 10, -6, -6, 10, 2, 2, -2], [-3, 8, 1, 7, -3, -10, 7, -3, -6, -4, -4, -4, -5], [-4, -6, 1, -11, 4, 3, -7, -1, 4, 4, 6, 1, 5], [-11, -16, -1, 2, 1, 7, 3, -5, -2, 9, 1, 0, 9], [-1, 17, -4, -4, -3, -6, -5, 3, 2, -9, -5, 2, -2], [-16, 9, -5, -9, 1, 3, -3, 2, 6, -3, 3, -3, 1], [-3, 5, 5, 6, -5, -4, 10, 0, -2, -2, 3, -4, -2], [-8, 8, -7, -5, -7, 2, -2, 7, -4, 0, -2, 4, -1], [3, 3, 2, 1, 5, 3, 15, -7, -4, 6, -1, 2, 4], [9, -3, 3, 7, 1, 4, 3, -4, 2, -3, -1, 1, -2], [7, -13, 2, 10, -6, -8, 3, -8, -2, 8, 1, -2, 4], [25, -14, 10, 3, -7, -1, 1, -4, 0, 6, 5, -1, 12], [2, 2, 1, 2, -6, 1, -3, 5, 0, -1, -2, -1, 5], [-12, 10, -8, -8, 3, -1, 1, 4, 8, -8, -2, -2, -7], [-16, 6, 4, 4, 5, 0, -6, -4, -6, -4, 4, -1, -1], [-1, -2, -2, -8, 0, 3, -7, 5, 10, 3, 2, -3, 7], [-1, 9, 4, 3, -4, 2, -5, 0, 5, -10, -7, -5, -3], [-12, -8, 2, -12, 9, -1, 2, -6, -1, 5, 5, 4, 2], [-4, -20, 11, 6, 3, 1, 8, -13, -4, 8, 7, 1, 5], [26, -5, 4, -4, -3, -2, 1, 0, -4, 1, 9, 4, 2], [-5, 4, -3, -1, -9, 4, -15, 5, -4, -10, -6, -4, 1], [1, -4, 1, 4, -17, -5, -6, 3, -6, -15, 2, -7, -3], [3, 14, 6, -1, -2, 5, -8, 2, 4, 1, 0, -3, 2], [-20, 11, -2, 2, 4, -3, -3, -3, 3, -7, 1, -1, -7], [-16, 8, 4, 5, -6, -2, -7, 8, -8, -10, 3, -7, -3], [-17, 5, 0, 9, -17, 3, -11, 3, -6, -18, -2, -10, -8], [-20, 3, 4, -8, -2, 4, -7, 3, 3, -3, 0, -3, 1], [-16, 7, 2, 6, -8, 4, -12, 0, 0, -15, -4, -7, 0], [2, -4, 6, 8, 5, 2, -1, -5, -2, 1, 4, 1, -2], [6, -6, 5, -4, 9, -2, 2, -8, 4, 8, 2, 7, 2], [-5, 5, -8, 9, 2, -9, 7, -2, -5, -1, -5, 7, -4], [-7, -4, 2, 10, 5, -7, 17, -12, -9, 9, -5, 2, 0], [1, 4, 4, 8, -3, 4, -5, 8, -3, -14, 2, -8, 1], [10, 3, 6, 10, -4, -2, -9, 1, 4, -6, 2, -4, 0], [-20, -17, -1, 3, 1, -5, 14, -4, -4, 2, 0, 2, 2], [-21, 1, -4, 0, 10, 8, 2, -6, 2, 7, -2, 1, 1], [10, 0, 0, -8, 11, 2, 1, -3, 1, 15, 2, 8, 8], [-17, 10, -12, -2, 4, -2, 0, 1, -1, 9, -6, 3, -3], [11, 1, 0, -2, -4, -3, 2, 0, 2, 1, 0, -3, 3], [17, 6, -6, -10, 1, -3, -4, 4, 9, 6, 2, 5, 7], [-9, -5, 8, 5, -4, -8, 2, -6, -10, -2, 5, -3, -1], [11, -4, -2, -3, -2, 12, 2, 6, 0, -2, -1, 3, -1], [22, 0, -6, -2, -1, -1, -3, 4, 0, 3, -1, 2, 6], [5, -1, 2, -14, -3, -5, -5, 7, 4, 9, -2, 4, 4], [32, -1, 0, -7, 2, 1, 1, -7, 0, 7, 0, 4, 4], [-17, 13, 2, -5, 3, -1, 3, -3, 6, -2, -3, -2, -2], [-3, -2, -10, 3, 0, -5, 4, 2, 0, -2, -5, -1, -3], [20, 5, 4, -2, 0, -6, -3, 1, 6, 1, 5, -1, 4], [-4, -2, 3, 8, -14, -1, 2, -2, -6, -11, 3, -7, -7], [3, 20, 0, 5, 1, 9, -8, 6, -2, -18, -3, -6, -6], [-23, -3, 1, 0, -3, -6, -4, 0, -2, -8, 7, -3, 1], [-16, -8, -2, 7, 6, 10, 2, 2, -6, 8, 3, -2, -1], [-11, -6, 10, 5, -4, -6, 8, -16, 2, -3, -4, -5, 2], [-5, 3, 1, 1, 11, -4, 10, -6, 6, 4, 2, 6, 1], [-12, 3, 2, 8, -4, 1, 1, -3, -10, 6, -5, 0, -4], [14, -3, -3, -2, 3, 2, 4, 0, -1, -2, 1, 5, 5], [-20, -8, -4, -5, 3, 1, 2, -2, 4, 6, -3, 3, -4], [8, 10, 2, -8, 6, 1, -2, -2, 2, -4, -5, -2, 0], [-7, 2, -10, -10, -3, -4, -5, 2, 2, 4, -12, 3, -3], [-13, 6, -3, -10, 14, 7, 0, 1, 6, 5, -4, 5, -1], [2, -2, 2, 4, 0, 2, 9, -3, 3, -1, -6, 5, -3], [-9, 11, -2, 1, 3, -5, -3, -7, -5, 3, -2, 1, 1], [8, -12, 1, -2, 8, 4, -8, -1, -2, 5, 4, 5, 6], [-14, -8, -3, -7, 4, 1, -6, 0, -4, 10, 3, 5, 5], [28, 3, -2, -10, -3, 5, -8, 4, -3, -5, 2, 6, 0], [2, 0, -10, -8, 13, 8, 7, -3, 3, 8, -3, 2, -3], [-1, 9, 7, -5, 1, 5, -2, 8, 6, -3, 3, -7, 1], [-20, 2, 0, -5, -10, -2, -4, 4, -2, -1, -7, 0, -2], [-1, -3, 4, 6, 6, -2, 5, -7, -5, 8, -4, -2, 0], [19, 8, -10, -6, 2, -1, -5, 9, 1, -2, -5, -4, -2], [31, -7, 3, -9, 2, 4, 4, -2, 8, 15, -1, 8, 14], [2, -6, 12, 9, -4, 4, 0, -4, 0, -5, 6, -2, 4], [9, 1, 0, -1, -2, 3, -2, 1, 6, -4, -5, 4, -1], [-29, -2, 1, 12, 0, -3, 6, -7, 2, 2, -3, -2, -1], [3, -1, 2, -1, 4, 5, -5, 3, 2, 4, -8, 3, 1], [4, -13, 12, -2, 0, 2, 5, -4, 2, -3, 5, -5, -3], [14, -12, -1, 0, -9, -6, -1, 2, -6, 1, 3, 4, -5], [8, -6, 8, -9, 5, 3, 3, 0, 3, 3, 0, 3, 7], [-8, -4, 8, 11, -10, -5, -3, -5, -7, -8, -4, -3, -1], [-29, 5, 2, 10, 5, -3, 13, -7, -1, -6, -5, -7, -9], [-7, -1, 6, 6, -5, 3, -1, 2, 2, -5, 6, -8, -3], [23, 6, -3, -3, -10, 4, -16, 14, 4, -16, 1, -3, -10], [15, -7, -2, -2, -2, 1, 5, -1, 7, 10, 2, -2, 2], [2, -12, 8, 7, -4, 7, 2, 0, 0, -8, 5, 0, -1], [11, 0, -6, -1, -12, 7, -13, 7, 0, -14, 0, -7, -7], [0, -1, 6, 0, 13, -1, 17, -10, 5, 18, 1, 7, 9], [1, -3, 0, 5, -10, 2, 3, 0, -4, 0, 2, -8, 1], [-19, 5, 4, -2, -3, 7, 0, 3, -5, -15, 3, -6, -2], [6, 2, 0, -17, 4, 1, -7, 7, -1, 4, 6, 3, -1], [-11, 6, -12, -2, 0, 2, 1, 0, 0, -6, -2, 0, -8], [2, -3, 2, 12, -6, 2, -4, -4, -4, 0, 3, 2, -6], [9, -14, 9, 6, -2, 3, 14, -3, 2, 5, 2, 3, 3], [3, -11, -6, -5, -1, 2, -2, 1, 3, 2, -7, 6, 2], [-5, 13, -1, -1, 8, -3, 3, 0, 0, -2, 10, -3, -9], [-19, 11, -6, 6, -1, 2, 4, -3, -2, 5, -3, 2, -1], [32, -3, -8, -15, -7, 3, -14, 11, 0, 2, 8, 4, 12], [8, -7, 0, -2, 9, -2, 8, -8, 1, 11, -2, 10, -2], [16, -4, 0, -1, -12, 8, -7, 8, -6, -7, 4, 3, 2], [-7, 0, 5, 3, 7, -2, -6, 0, 4, -7, 6, 1, 1], [0, 2, -3, 2, -3, 6, -7, 6, -2, -1, 2, 2, -5], [-9, 16, 2, 9, 13, 0, 6, -4, 4, 0, -1, 4, 2], [-5, 3, 4, 9, 5, -2, 10, -1, -2, -5, -4, 5, -3], [-18, 3, -4, 14, -4, -7, 9, -3, -6, 2, -8, 0, -14], [-7, -15, 7, 0, 8, 7, 0, -5, -6, 12, 5, 8, 11], [34, 6, 4, -13, -1, 5, -10, 13, 4, -6, 11, 0, 4], [14, 4, -12, -8, 4, -5, 2, 2, -2, 6, -3, 0, 0], [13, -10, 3, 0, -11, 3, -12, 6, -4, -7, -1, -8, -1], [-3, 12, -14, -10, -3, 0, -12, 13, 0, -12, 5, -1, -9], [14, -1, -3, -8, 8, 6, -11, 5, 4, 0, 10, 2, 7]]
